# Partially Monotone Layer

Partially monotome layer (`pmlayer`) is a library for neural network models.
It provides sevral neural network layers to add monotonicity constraints on neural network models.
Documents are available at [https://ibm.github.io/pmlayer/](https://ibm.github.io/pmlayer/)


# Citation

Please consider citing this paper.
> H. Yanagisawa, K. Miyaguchi, and T. Katsuki, "Hierarchical Lattice Layer for Partially Monotone Regression," NeurIPS 2022.
